Quick Start — rpl-pack 0.0.1 documentation

# Quick Start

## Registration

Using rpl-pack requires an active RPL account at the RPL Website. Once you’ve created an account, you can then follow the installation guide below.

## Installation

It’s a good idea to keep everything contained in a virtual environment, which can be created either with Python’s venv module or with Conda.

    $ python3 -m venv .venv

    $ conda create --name .venv

Install rpl-pack with pip.

    (.venv) $ pip install rpl-pack

Great! If everything went accordingly then we can move on to the Tutorials section to learn more about the API, what is included, and how to leverage it in your own scripts. In case something went wrong, please head over to the FAQ section or Contact Us.